==> imime-0.0.1.tar.gz: imime-0.0.1/imime.c <==
/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 * gtkimmoduleime
 * Copyright (C) 2003 Takuro Ashie
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * $Id: imime.c,v 1.2 2003/05/05 13:33:30 makeinu Exp $
 */

#include <gtk/gtkimmodule.h>
#include "gtkimcontextime.h"

#include <string.h>

static const GtkIMContextInfo ime_info = { 
    "win32ime",    /* ID */
    "Windows IME", /* Human readable name */
    "gtk+",	       /* Translation domain */
    "",            /* Dir for bindtextdomain (not strictly needed for "gtk+") */
    ""             /* Languages for which this module is the default */
};

static const GtkIMContextInfo *info_list[] = {
    &ime_info,
};

void
im_module_init (GTypeModule *module)
{
    gtk_im_context_ime_register_type (module);
}

void 
im_module_exit (void)
{
}

void 
im_module_list (const GtkIMContextInfo ***contexts,
                int                      *n_contexts)
{
    *contexts = info_list;
    *n_contexts = G_N_ELEMENTS (info_list);
}

GtkIMContext *
im_module_create (const gchar *context_id)
{
    if (!strcmp (context_id, "win32ime"))
        return gtk_im_context_ime_new();
    else
        return NULL;
}

==> imime-0.0.2.tar.gz: imime-0.0.2/imime.c <==
/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 * gtkimmoduleime
 * Copyright (C) 2003 Takuro Ashie
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * $Id: imime.c,v 1.3 2003/05/07 12:42:50 makeinu Exp $
 */

#include <gtk/gtkimmodule.h>
#include "gtkimcontextime.h"

#include <string.h>

static const GtkIMContextInfo ime_info = { 
    "win32ime",    /* ID */
    "Windows IME", /* Human readable name */
    "gtk+",	       /* Translation domain */
    "",            /* Dir for bindtextdomain (not strictly needed for "gtk+") */
    "*",           /* Languages for which this module is the default */
};

static const GtkIMContextInfo *info_list[] = {
    &ime_info,
};

void
im_module_init (GTypeModule *module)
{
    gtk_im_context_ime_register_type (module);
}

void 
im_module_exit (void)
{
}

void 
im_module_list (const GtkIMContextInfo ***contexts,
                int                      *n_contexts)
{
    *contexts = info_list;
    *n_contexts = G_N_ELEMENTS (info_list);
}

GtkIMContext *
im_module_create (const gchar *context_id)
{
    if (!strcmp (context_id, "win32ime"))
        return gtk_im_context_ime_new();
    else
        return NULL;
}
